function [f] = ode_trypsin_osc(~,y,k,kflow,xo)

 %% Variables
% Make descriptors and number them for y-vector, so the rate eqns are
% easier on the eye.
    dTg      = 1;
    dTr      = 2;
    daaI     = 3;
    daI      = 4;
    dI       = 5;
    dTr_Tg   = 6;
    dTr_aaI  = 7;
    % checks:
        daaI_Tr  = 8;
        daI_Tr   = 9;
        dI_Tr    = 10;
        daaIOH   = 11;
        daIOH    = 12;
        dIOH     = 13;

% Species are coupled to y-vector. 
    Tg       = y(dTg);
    Tr       = y(dTr);
    aaI      = y(daaI);
    aI       = y(daI);
    I        = y(dI);
    Tr_Tg    = y(dTr_Tg);
    Tr_aaI   = y(dTr_aaI);
	aaI_Tr   = y(daaI_Tr);
	aI_Tr    = y(daI_Tr); 
	I_Tr     = y(dI_Tr);  
	aaIOH    = y(daaIOH); 
	aIOH     = y(daIOH);  
	IOH      = y(dIOH);   

%% RATE EQNS

f(dTg)      = -(k.kf_auto_tr*Tr+k.kc_auto_tg*Tg+kflow)*Tg+k.kr_auto_tr*Tr_Tg+kflow*xo(dTg);
        
f(dTr)      = -(k.kf_auto_tr*Tg+(k.kf_act+k.kf_inh_aai)*aaI+k.kf_inh_ai*aI+k.kf_inh_i*I+kflow)*Tr...
			  +(k.kr_auto_tr+2*k.kc_auto_tr)*Tr_Tg+(k.kr_act+k.kc_act)*Tr_aaI+k.kc_auto_tg*Tg*Tg+kflow*xo(dTr); 

f(daaI)     = -((k.kf_act+k.kf_inh_aai)*Tr+k.kf_degr_aai+kflow)*aaI+k.kr_act*Tr_aaI+kflow*xo(daaI);

f(daI)      = k.kc_act*Tr_aaI-((k.Vmax_delay/(k.Km_delay+aI))+k.kf_inh_ai*Tr+k.kf_degr_ai+kflow)*aI;

f(dI)       = (k.Vmax_delay/(k.Km_delay+aI))*aI-(k.kf_inh_i*Tr+k.kf_degr_i+kflow)*I;

f(dTr_Tg)   = k.kf_auto_tr*Tg*Tr-(k.kr_auto_tr+k.kc_auto_tr+kflow)*Tr_Tg;
			       
f(dTr_aaI) 	= k.kf_act*Tr*aaI-(k.kr_act+k.kc_act+kflow)*Tr_aaI;
 
f(daaI_Tr)	= k.kf_inh_aai*aaI*Tr-kflow*aaI_Tr;  
f(daI_Tr)   = k.kf_inh_ai*aI*Tr-kflow*aI_Tr;
f(dI_Tr)    = k.kf_inh_i*I*Tr-kflow*I_Tr;
f(daaIOH)   = k.kf_degr_aai*aaI-kflow*aaIOH; 
f(daIOH)    = k.kf_degr_ai*aI-kflow*aIOH;
f(dIOH)     = k.kf_degr_i*I-kflow*IOH;

    % Turn from row to column vector for solver function to be able to read
    % it. 
    f       = f';
end
